==> deverhood-react-1.16.51.tgz: package/src/reducers/user.js <==
import { USER_API } from "../actions/actionType";
import Super from "./super";
const defaultState = {
  list: [],
  data: {},
  pendings: [],
  pending: {},
  institutes: [],
  verify: {},
  predefinedAccounts: [],
  predefinedAccount: {},
  problems:[]
};

export default (state = defaultState, action) => {
  let reducer = new Super(state, action);
  switch (action.type) {
    case USER_API.SELF.GETID.SUCCESS:
      return reducer.get();
    case USER_API.SIGNUP.GET.SUCCESS:
      return reducer.get("pending");
    case USER_API.VERIFY.GET.SUCCESS:
      return reducer.get("verify");
    case USER_API.VERIFY_CODE.GET.SUCCESS:
      return reducer.get("verify");
    case USER_API.SELF.ALL.SUCCESS:
      return reducer.list("list", "username");
    case USER_API.SIGNUP.ALL.SUCCESS:
      return { ...state, pendings: reducer.get("pendings").pendings };
    case USER_API.SELF.CLEAR.SUCCESS:
      return { ...state, list: [], predefinedAccounts: []};
    case USER_API.SELF.POST.SUCCESS:
      return reducer.post();
    case USER_API.SELF.PUT.SUCCESS:
      return reducer.put();
    case USER_API.SELF.DEL.SUCCESS:
      return {
        ...state,
        list: state.list.filter(v => v.username !== action.data)
      };
    case USER_API.SELF.SEARCH.SUCCESS:
      return reducer.search();
    case USER_API.INSTITUTE.ALL.SUCCESS:
      return reducer.list("institutes");
    case USER_API.PREDEFINED.ALL.SUCCESS:
      return reducer.list("predefinedAccounts");
    case USER_API.PREDEFINED.GET.SUCCESS:
      return reducer.get("predefinedAccount");
    case USER_API.PREDEFINED.PUT.SUCCESS:
      return reducer.put("predefinedAccount", "predefinedAccounts");
    case USER_API.PREDEFINED.DEL.SUCCESS:
      return reducer.delete("predefinedAccounts");
    case USER_API.IMPORT.POST.SUCCESS:
      return reducer.list("problems");
    default:
      return state;
  }
};

==> deverhood-react-1.16.59.tgz: package/src/reducers/user.js <==
import { USER_API, COMPONENT } from "../actions/actionType";
import Super from "./super";
const defaultState = {
  list: [],
  data: {},
  pendings: [],
  pending: {},
  institutes: [],
  verify: {},
  predefinedAccounts: [],
  predefinedAccount: {},
  problems: [],
  isInstituteOut: false,
  isUserOut: false
};

export default (state = defaultState, action) => {
  let reducer = new Super(state, action);
  switch (action.type) {
    case USER_API.SELF.GETID.SUCCESS:
      return reducer.get();
    case USER_API.SIGNUP.GET.SUCCESS:
      return reducer.get("pending");
    case USER_API.VERIFY.GET.SUCCESS:
      return reducer.get("verify");
    case USER_API.VERIFY_CODE.GET.SUCCESS:
      return reducer.get("verify");
    case USER_API.SELF.ALL.SUCCESS:
      return reducer.list("list", "username");
    case USER_API.SIGNUP.ALL.SUCCESS:
      return reducer.list("pendings", "username");
    case USER_API.SELF.CALLBACK_OUT.SUCCESS:
      return { ...state, isUserOut: true };
    case USER_API.INSTITUTE.CALLBACK_OUT.SUCCESS:
      return { ...state, isInstituteOut: true };
    case USER_API.SELF.CLEAR.SUCCESS:
      return { ...state, list: [], predefinedAccounts: [], isUserOut: false };
    case USER_API.SIGNUP.CLEAR.SUCCESS:
      return { ...state, pendings: [] };
    case USER_API.INSTITUTE.CLEAR.SUCCESS:
      return { ...state, institutes: [], isInstituteOut: false };
    case USER_API.SELF.POST.SUCCESS:
      return reducer.post();
    case USER_API.SELF.PUT.SUCCESS:
      return reducer.put();
    case USER_API.SELF.DEL.SUCCESS:
      return {
        ...state,
        list: state.list.filter(v => v.username !== action.data)
      };
    case USER_API.SELF.SEARCH.SUCCESS:
      return reducer.search();
    case USER_API.INSTITUTE.ALL.SUCCESS:
      return reducer.list("institutes");
    case USER_API.PREDEFINED.ALL.SUCCESS:
      return reducer.list("predefinedAccounts");
    case USER_API.PREDEFINED.GET.SUCCESS:
      return reducer.get("predefinedAccount");
    case USER_API.PREDEFINED.PUT.SUCCESS:
      return reducer.put("predefinedAccount", "predefinedAccounts");
    case USER_API.PREDEFINED.DEL.SUCCESS:
      return reducer.delete("predefinedAccounts");
    case USER_API.IMPORT.POST.SUCCESS:
      return reducer.list("problems");
    case USER_API.STAT.ALL.SUCCESS:
      return reducer.list("list", "username");
    default:
      return state;
  }
};
